==> haskell-commonmark-pandoc-0.2.2.3-37.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.3
visibility:           public
id:                   commonmark-pandoc-0.2.2.3-IZb1CpXfDm2BJzfrj4CsLd
key:                  commonmark-pandoc-0.2.2.3-IZb1CpXfDm2BJzfrj4CsLd
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  599922517af61a7022edf1234f6b7c67
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.3-IZb1CpXfDm2BJzfrj4CsLd
depends:
    base-4.18.2.1 commonmark-0.2.6.1-AFyWZFKNc0cCLBasjsgiue
    commonmark-extensions-0.2.5.5-DwZ7ll7vAlW5lAUZnqjmju
    pandoc-types-1.23.1-84C04huNeQE19kRVi0p0kr text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-pandoc-0.2.2.3-38-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.2.2.3
visibility:           public
id:                   commonmark-pandoc-0.2.2.3-EdyRHZtjc1PIJmSuyj87HK
key:                  commonmark-pandoc-0.2.2.3-EdyRHZtjc1PIJmSuyj87HK
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  a1076b9e1b5a33fbc97c9026ac5a188c
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.2.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.2.2.3-EdyRHZtjc1PIJmSuyj87HK
depends:
    base-4.18.2.1 commonmark-0.2.6.1-GUdQFBTT0dEFTdPQeDlNIQ
    commonmark-extensions-0.2.5.5-D3kq1Kzu7BvHjswrPw309p
    pandoc-types-1.23.1-8LyhSCLdqfo18RNKTPAafp text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
